EOG
-------

Main
^^^^^^^^^^^^^^^^
*eog_process()*
"""""""""""""""""
.. autofunction:: neurokit2.eog.eog_process

*eog_analyze()*
""""""""""""""""
.. autofunction:: neurokit2.eog.eog_analyze

*eog_plot()*
""""""""""""""""""""""
.. autofunction:: neurokit2.eog.eog_plot


Preprocessing
^^^^^^^^^^^^^^^^
*eog_clean()*
""""""""""""""
.. autofunction:: neurokit2.eog.eog_clean

*eog_features()*
""""""""""""""""""
.. autofunction:: neurokit2.eog.eog_features

*eog_peaks()*
""""""""""""""
.. autofunction:: neurokit2.eog.eog_peaks


Analysis
^^^^^^^^^
*eog_eventrelated()*
""""""""""""""""""""""
.. autofunction:: neurokit2.eog.eog_eventrelated

*eog_intervalrelated()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.eog.eog_intervalrelated


Miscellaneous
^^^^^^^^^^^^^^^^
*eog_findpeaks()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.eog.eog_findpeaks


.. automodule:: neurokit2.eog
   :members:
   :exclude-members: eog_process, eog_analyze, eog_plot, eog_clean, eog_features, eog_peaks, eog_eventrelated, eog_intervalrelated, eog_findpeaks